import { Action } from "../core/Action.js";
/**
 * Input bindings.
 *
 * @group Settings
 */
export declare class Bindings<T> {
    /**
     * The default bindings.
     */
    defaultActions: Map<T, Action>;
    /**
     * A collection that maps keys to actions.
     */
    actions: Map<T, Action>;
    /**
     * Constructs new input bindings.
     */
    constructor();
    /**
     * Resets the current bindings to match the default bindings.
     *
     * @return This instance.
     */
    reset(): Bindings<T>;
    /**
     * Establishes default bindings and resets the current bindings.
     *
     * @param actions - A collection that maps keys to actions.
     * @return This instance.
     */
    setDefault(actions: Map<T, Action>): Bindings<T>;
    /**
     * Clears the default bindings.
     *
     * @return This instance.
     */
    clearDefault(): Bindings<T>;
    /**
     * Clears the current bindings.
     *
     * @return This instance.
     */
    clear(): Bindings<T>;
    /**
     * Copies the given bindings, including the default bindings.
     *
     * @param bindings - Bindings.
     * @return This instance.
     */
    copy(bindings: Bindings<T>): Bindings<T>;
    /**
     * Clones these bindings.
     *
     * @return The cloned bindings.
     */
    clone(): Bindings<T>;
    /**
     * Copies the given JSON data.
     *
     * @param json - The JSON data.
     * @return This instance.
     */
    fromJSON(json: Bindings<T>): Bindings<T>;
    /**
     * Checks if the given key is bound to an action.
     *
     * @param key - A key.
     * @return Whether the given key is bound to an action.
     */
    has(key: T): boolean;
    /**
     * Returns the action that is bound to the given key.
     *
     * @param key - A key.
     * @return The action, or undefined if the key is not bound to any action.
     */
    get(key: T): Action | undefined;
    /**
     * Binds a key to an action.
     *
     * @param key - A key.
     * @param action - An action.
     * @return This instance.
     */
    set(key: T, action: Action): Bindings<T>;
    /**
     * Unbinds a key.
     *
     * @param key - The key.
     * @return Whether the binding existed.
     */
    delete(key: T): boolean;
    toJSON(): Record<string, unknown>;
}
